@@ -10,8 +10,10 @@ from importlib_metadata import PackagePath
 from app_utils.testing import NoSocketsTestCase
 
 from ..models import Distribution
+from .factories import DistributionFactory
 from .testdata import create_testdata
 
+MODULE_PATH_CORE = "package_monitor.core"
 MODULE_PATH_MODELS = "package_monitor.models"
 MODULE_PATH_MANAGERS = "package_monitor.managers"
 
@@ -50,70 +52,76 @@ class DjangoAppConfigStub:
 
 
 def distributions_stub():
-    return [
-        ImportlibDistributionStub(
-            name="dummy-1",
-            version="0.1.1",
-            files=["dummy_1/file_1.py", "dummy_1/__init__.py"],
-            homepage_url="homepage-dummy-1",
-            description="description-dummy-1",
-        ),
-        ImportlibDistributionStub(
-            name="Dummy-2",
-            version="0.2.0",
-            files=[
-                "dummy_2/file_2.py",
-                "dummy_2a/__init__.py",
-                "dummy_2b/__init__.py",
-            ],
-            requires=["dummy-1<0.3.0"],
-            homepage_url="homepage-dummy-2",
-            description="package name starts with capital, dependency to Python version",
-        ),
-        ImportlibDistributionStub(
-            name="dummy-3",
-            version="0.3.0",
-            files=["dummy_3/file_3.py", "dummy_3/__init__.py"],
-            requires=["dummy-1>0.1.0", "dummy-4", 'dummy-2==0.1.0; extra == "certs"'],
-            description="invalid extra requirement for dummy-2",
-        ),
-        ImportlibDistributionStub(
-            name="dummy-4",
-            version="1.0.0b2",
-            files=["dummy_4/file_4.py"],
-            description="only prereleases",
-        ),
-        ImportlibDistributionStub(
-            name="dummy-5",
-            version="2009r",
-            files=["dummy_5/file_5.py"],
-            description="Invalid version number",
-        ),
-        ImportlibDistributionStub(
-            name="dummy-6",
-            version="0.1.0",
-            files=["dummy_6/file_6.py"],
-            requires=[
-                "dummy-8<=0.4;python_version<'3.7'",
-                "dummy-8<=0.3;python_version<'2.0'",
-            ],
-            description="yanked release",
-        ),
-        ImportlibDistributionStub(
-            name="dummy-7",
-            version="0.1.0",
-            files=["dummy_7/file_7.py"],
-            description="Python version requirements on PyPI",
-        ),
-        # Python version requirements as marker
-        ImportlibDistributionStub(
-            name="dummy-8",
-            version="0.1.0",
-            files=["dummy_8/file_8.py"],
-            homepage_url=None,
-            description=None,
-        ),
-    ]
+    return iter(
+        [
+            ImportlibDistributionStub(
+                name="dummy-1",
+                version="0.1.1",
+                files=["dummy_1/file_1.py", "dummy_1/__init__.py"],
+                homepage_url="homepage-dummy-1",
+                description="description-dummy-1",
+            ),
+            ImportlibDistributionStub(
+                name="Dummy-2",
+                version="0.2.0",
+                files=[
+                    "dummy_2/file_2.py",
+                    "dummy_2a/__init__.py",
+                    "dummy_2b/__init__.py",
+                ],
+                requires=["dummy-1<0.3.0"],
+                homepage_url="homepage-dummy-2",
+                description="package name starts with capital, dependency to Python version",
+            ),
+            ImportlibDistributionStub(
+                name="dummy-3",
+                version="0.3.0",
+                files=["dummy_3/file_3.py", "dummy_3/__init__.py"],
+                requires=[
+                    "dummy-1>0.1.0",
+                    "dummy-4",
+                    'dummy-2==0.1.0; extra == "certs"',
+                ],
+                description="invalid extra requirement for dummy-2",
+            ),
+            ImportlibDistributionStub(
+                name="dummy-4",
+                version="1.0.0b2",
+                files=["dummy_4/file_4.py"],
+                description="only prereleases",
+            ),
+            ImportlibDistributionStub(
+                name="dummy-5",
+                version="2009r",
+                files=["dummy_5/file_5.py"],
+                description="Invalid version number",
+            ),
+            ImportlibDistributionStub(
+                name="dummy-6",
+                version="0.1.0",
+                files=["dummy_6/file_6.py"],
+                requires=[
+                    "dummy-8<=0.4;python_version<'3.7'",
+                    "dummy-8<=0.3;python_version<'2.0'",
+                ],
+                description="yanked release",
+            ),
+            ImportlibDistributionStub(
+                name="dummy-7",
+                version="0.1.0",
+                files=["dummy_7/file_7.py"],
+                description="Python version requirements on PyPI",
+            ),
+            # Python version requirements as marker
+            ImportlibDistributionStub(
+                name="dummy-8",
+                version="0.1.0",
+                files=["dummy_8/file_8.py"],
+                homepage_url=None,
+                description=None,
+            ),
+        ]
+    )
 
 
 def get_app_configs_stub():
@@ -238,9 +246,9 @@ def requests_get_stub(*args, **kwargs):
     return r
 
 
-@patch(MODULE_PATH_MANAGERS + ".requests", auto_spec=True)
-@patch(MODULE_PATH_MANAGERS + ".django_apps", spec=True)
-@patch(MODULE_PATH_MANAGERS + ".distributions", spec=True)
+@patch(MODULE_PATH_CORE + ".requests", auto_spec=True)
+@patch(MODULE_PATH_CORE + ".django_apps", spec=True)
+@patch(MODULE_PATH_MANAGERS + ".importlib_metadata.distributions", spec=True)
 class TestDistributionsUpdateAll(NoSocketsTestCase):
     def test_all_packages_detected(
         self, mock_distributions, mock_django_apps, mock_requests
@@ -447,7 +455,7 @@ class TestDistributionsUpdateAll(NoSocketsTestCase):
         self.assertEqual(obj.latest_version, "0.4.0")
         self.assertTrue(obj.is_outdated)
 
-    @patch(MODULE_PATH_MANAGERS + ".sys")
+    @patch(MODULE_PATH_CORE + ".sys")
     def test_handle_release_with_python_requirement(
         self, mock_sys, mock_distributions, mock_django_apps, mock_requests
     ):
@@ -530,3 +538,26 @@ class TestDistributionCurrentlySelected(NoSocketsTestCase):
         self.assertEqual(
             set(result.values_list("name", flat=True)), {"dummy-1", "dummy-3"}
         )
+
+
+@patch(MODULE_PATH_MANAGERS + ".PACKAGE_MONITOR_SHOW_ALL_PACKAGES", True)
+@patch(MODULE_PATH_MANAGERS + ".PACKAGE_MONITOR_INCLUDE_PACKAGES", None)
+class TestDistributionBuildInstallCommand(NoSocketsTestCase):
+    def test_all_packages(self):
+        # given
+        DistributionFactory(name="alpha", latest_version="1.2.0")
+        DistributionFactory(name="bravo", latest_version="2.1.0")
+        # when
+        result = Distribution.objects.order_by("name").build_install_command()
+        # then
+        self.assertEqual(result, "pip install alpha==1.2.0 bravo==2.1.0")
+
+    def test_should_stay_within_max_line_length(self):
+        # given
+        DistributionFactory.create_batch(size=500)
+        # when
+        result = Distribution.objects.all().build_install_command()
+        # then
+        print(result)
+        print(len(result))
+        self.assertLessEqual(len(result), 4095)
